Database-agnostic JSON schema discovery

Create and merge json schemas, with occurence counting


Quickstart
----------

Start with ``Empty`` or using ``make_schema()`` and merge with json-like python objects using ``+=``

Visualize the resulting schema with ``dumps()`` or by printing the object

Get a sense of the overall structure with ``statistics()``
